@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.19 2006/03/19 20:19:27 khlut Exp $
+# $Id: mplayer.pl,v 1.20 2006/03/22 21:02:09 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -74,7 +74,7 @@ sub shut{
     }else{			#if it again not respond kill it
         kill -9 => $slvp;
 	kill(-9 => $sl2p) || print "kill_error: $!\n" if $sl2p;
-	print "\nrun=0\n";    
+#	print "\nrun=0\n";    
 	exit 0;	
     }
     return;
@@ -97,7 +97,7 @@ sub normal_exit{
 	kill 9 => $sl2p;
 	waitpid $sl2p, 0;
     }
-    print "\nrun=0\n";
+#    print "\nrun=0\n";
     exit 0;
 }
 
@@ -184,6 +184,7 @@ sub ofilt{
 		    print "url=$s";
 		}
 	    }elsif($s =~ m/^[AV]:/ || $s =~ m/^Pos:/){
+		$s =~ s/ \033\[J$//;
 		print "frame=$s";
 	    }else{
 		print $s;
